@@ -9,5 +9,5 @@ elif 'ROOTSYS' in os.environ:
     c.ServerApp.extra_static_paths.append(os.path.join(os.environ['ROOTSYS'], 'js/'))
 else:
     # Fall back to CMAKE_INSTALL_PREFIX/CMAKE_INSTALL_JSROOTDIR, e.g., for a system installation
-    c.NotebookApp.extra_static_paths.append(os.path.join("/Volumes/HD2/build/ws/BUILDTYPE/Release/LABEL/mac1015/V/6-26/install/ROOT", "js"))
-    c.ServerApp.extra_static_paths.append(os.path.join("/Volumes/HD2/build/ws/BUILDTYPE/Release/LABEL/mac1015/V/6-26/install/ROOT", "js"))
+    c.NotebookApp.extra_static_paths.append(os.path.join("/Users/sftnight/build/ws/BUILDTYPE/Release/LABEL/mac11/V/6-26/install/ROOT", "js"))
+    c.ServerApp.extra_static_paths.append(os.path.join("/Users/sftnight/build/ws/BUILDTYPE/Release/LABEL/mac11/V/6-26/install/ROOT", "js"))
